package com.aucma.base.service.impl;

import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.aucma.base.mapper.BaseProductLineMapper;
import com.aucma.base.domain.BaseProductLine;
import com.aucma.base.service.IBaseProductLineService;

/**
 * 产线信息Service业务层处理
 * 
 * @author Yinq
 * @date 2023-09-19
 */
@Service
public class BaseProductLineServiceImpl implements IBaseProductLineService 
{
    @Autowired
    private BaseProductLineMapper baseProductLineMapper;

    /**
     * 查询产线信息
     * 
     * @param objId 产线信息主键
     * @return 产线信息
     */
    @Override
    public BaseProductLine selectBaseProductLineByObjId(Long objId)
    {
        return baseProductLineMapper.selectBaseProductLineByObjId(objId);
    }

    /**
     * 查询产线信息列表
     * 
     * @param baseProductLine 产线信息
     * @return 产线信息
     */
    @Override
    public List<BaseProductLine> selectBaseProductLineList(BaseProductLine baseProductLine)
    {
        return baseProductLineMapper.selectBaseProductLineList(baseProductLine);
    }

    /**
     * 新增产线信息
     * 
     * @param baseProductLine 产线信息
     * @return 结果
     */
    @Override
    public int insertBaseProductLine(BaseProductLine baseProductLine)
    {
        return baseProductLineMapper.insertBaseProductLine(baseProductLine);
    }

    /**
     * 修改产线信息
     * 
     * @param baseProductLine 产线信息
     * @return 结果
     */
    @Override
    public int updateBaseProductLine(BaseProductLine baseProductLine)
    {
        return baseProductLineMapper.updateBaseProductLine(baseProductLine);
    }

    /**
     * 批量删除产线信息
     * 
     * @param objIds 需要删除的产线信息主键
     * @return 结果
     */
    @Override
    public int deleteBaseProductLineByObjIds(Long[] objIds)
    {
        return baseProductLineMapper.deleteBaseProductLineByObjIds(objIds);
    }

    /**
     * 删除产线信息信息
     * 
     * @param objId 产线信息主键
     * @return 结果
     */
    @Override
    public int deleteBaseProductLineByObjId(Long objId)
    {
        return baseProductLineMapper.deleteBaseProductLineByObjId(objId);
    }

    /**
     * 查询质检工位顺序
     *
     * @param baseProductLine 产线信息
     * @return 产线信息
     */
    @Override
    public List<BaseProductLine> selectReportQualityStationCode(BaseProductLine baseProductLine)
    {
        return baseProductLineMapper.selectReportQualityStationCode(baseProductLine);
    }
}
